package cn.iocoder.yudao.module.system.controller.admin.houselocation;

import cn.iocoder.yudao.module.system.controller.admin.houselocation.vo.HouseLocationPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.houselocation.vo.HouseLocationRespVO;
import cn.iocoder.yudao.module.system.controller.admin.houselocation.vo.HouseLocationSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.houselocation.HouseLocationDO;
import cn.iocoder.yudao.module.system.service.houselocation.HouseLocationService;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.*;


@Tag(name = "管理后台 - 库位")
@RestController
@RequestMapping("/system/ware/house-location")
@Validated
public class HouseLocationController {

    @Resource
    private HouseLocationService houseLocationService;

    @PostMapping("/create")
    @Operation(summary = "创建库位")
    @PreAuthorize("@ss.hasPermission('ware:house-location:create')")
    public CommonResult<Long> createHouseLocation(@Valid @RequestBody HouseLocationSaveReqVO createReqVO) {
        return success(houseLocationService.createHouseLocation(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新库位")
    @PreAuthorize("@ss.hasPermission('ware:house-location:update')")
    public CommonResult<Boolean> updateHouseLocation(@Valid @RequestBody HouseLocationSaveReqVO updateReqVO) {
        houseLocationService.updateHouseLocation(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除库位")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('ware:house-location:delete')")
    public CommonResult<Boolean> deleteHouseLocation(@RequestParam("id") Long id) {
        houseLocationService.deleteHouseLocation(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得库位")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('ware:house-location:query')")
    public CommonResult<HouseLocationRespVO> getHouseLocation(@RequestParam("id") Long id) {
        HouseLocationDO houseLocation = houseLocationService.getHouseLocation(id);
        return success(BeanUtils.toBean(houseLocation, HouseLocationRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得库位分页")
    @PreAuthorize("@ss.hasPermission('ware:house-location:query')")
    public CommonResult<PageResult<HouseLocationRespVO>> getHouseLocationPage(@Valid HouseLocationPageReqVO pageReqVO) {
        PageResult<HouseLocationDO> pageResult = houseLocationService.getHouseLocationPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, HouseLocationRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出库位 Excel")
    @PreAuthorize("@ss.hasPermission('ware:house-location:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportHouseLocationExcel(@Valid HouseLocationPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<HouseLocationDO> list = houseLocationService.getHouseLocationPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "库位.xls", "数据", HouseLocationRespVO.class,
                        BeanUtils.toBean(list, HouseLocationRespVO.class));
    }

}