package cn.iocoder.yudao.module.system.service.houselocation;

import cn.iocoder.yudao.module.system.controller.admin.houselocation.vo.HouseLocationPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.houselocation.vo.HouseLocationSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.houselocation.HouseLocationDO;
import cn.iocoder.yudao.module.system.dal.mysql.houselocation.HouseLocationMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;


import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.HOUSE_LOCATION_NOT_EXISTS;

/**
 * 库位 Service 实现类
 *
 * @author 陈宾顺
 */
@Service
@Validated
public class HouseLocationServiceImpl implements HouseLocationService {

    @Resource
    private HouseLocationMapper houseLocationMapper;

    @Override
    public Long createHouseLocation(HouseLocationSaveReqVO createReqVO) {
        // 插入
        HouseLocationDO houseLocation = BeanUtils.toBean(createReqVO, HouseLocationDO.class);
        houseLocationMapper.insert(houseLocation);
        // 返回
        return houseLocation.getId();
    }

    @Override
    public void updateHouseLocation(HouseLocationSaveReqVO updateReqVO) {
        // 校验存在
        validateHouseLocationExists(updateReqVO.getId());
        // 更新
        HouseLocationDO updateObj = BeanUtils.toBean(updateReqVO, HouseLocationDO.class);
        houseLocationMapper.updateById(updateObj);
    }

    @Override
    public void deleteHouseLocation(Long id) {
        // 校验存在
        validateHouseLocationExists(id);
        // 删除
        houseLocationMapper.deleteById(id);
    }

    private void validateHouseLocationExists(Long id) {
        if (houseLocationMapper.selectById(id) == null) {
            throw exception(HOUSE_LOCATION_NOT_EXISTS);
        }
    }

    @Override
    public HouseLocationDO getHouseLocation(Long id) {
        return houseLocationMapper.selectById(id);
    }

    @Override
    public PageResult<HouseLocationDO> getHouseLocationPage(HouseLocationPageReqVO pageReqVO) {
        return houseLocationMapper.selectPage(pageReqVO);
    }

}