package cn.iocoder.yudao.module.system.service.robot;

import cn.iocoder.yudao.module.system.controller.admin.robot.vo.RobotInformationPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.robot.vo.RobotInformationSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.robot.RobotInformationDO;
import cn.iocoder.yudao.module.system.dal.mysql.robot.RobotInformationMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;


import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.ROBOT_INFORMATION_NOT_EXISTS;

/**
 * 车辆信息 Service 实现类
 *
 * @author 陈宾顺
 */
@Service
@Validated
public class RobotInformationServiceImpl implements RobotInformationService {

    @Resource
    private RobotInformationMapper informationMapper;

    @Override
    public Long createInformation(RobotInformationSaveReqVO createReqVO) {
        // 插入
        RobotInformationDO information = BeanUtils.toBean(createReqVO, RobotInformationDO.class);
        informationMapper.insert(information);
        // 返回
        return information.getId();
    }

    @Override
    public void updateInformation(RobotInformationSaveReqVO updateReqVO) {
        // 校验存在
        validateInformationExists(updateReqVO.getId());
        // 更新
        RobotInformationDO updateObj = BeanUtils.toBean(updateReqVO, RobotInformationDO.class);
        informationMapper.updateById(updateObj);
    }

    @Override
    public void deleteInformation(Long id) {
        // 校验存在
        validateInformationExists(id);
        // 删除
        informationMapper.deleteById(id);
    }

    private void validateInformationExists(Long id) {
        if (informationMapper.selectById(id) == null) {
            throw exception(ROBOT_INFORMATION_NOT_EXISTS);
        }
    }

    @Override
    public RobotInformationDO getInformation(Long id) {
        return informationMapper.selectById(id);
    }

    @Override
    public PageResult<RobotInformationDO> getInformationPage(RobotInformationPageReqVO pageReqVO) {
        return informationMapper.selectPage(pageReqVO);
    }

}