package cn.iocoder.yudao.module.system.service.robot;

import cn.iocoder.yudao.module.system.controller.admin.robot.vo.RobotTaskPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.robot.vo.RobotTaskSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.robot.RobotTaskDO;
import cn.iocoder.yudao.module.system.dal.mysql.robot.RobotTaskMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;


import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.TASK_NOT_EXISTS;

/**
 * 机器人任务主表 Service 实现类
 *
 * @author 陈宾顺
 */
@Service
@Validated
public class RobotTaskServiceImpl implements RobotTaskService {

    @Resource
    private RobotTaskMapper taskMapper;

    @Override
    public Long createTask(RobotTaskSaveReqVO createReqVO) {
        // 插入
        RobotTaskDO task = BeanUtils.toBean(createReqVO, RobotTaskDO.class);
        taskMapper.insert(task);
        // 返回
        return task.getId();
    }

    @Override
    public void updateTask(RobotTaskSaveReqVO updateReqVO) {
        // 校验存在
        validateTaskExists(updateReqVO.getId());
        // 更新
        RobotTaskDO updateObj = BeanUtils.toBean(updateReqVO, RobotTaskDO.class);
        taskMapper.updateById(updateObj);
    }

    @Override
    public void deleteTask(Long id) {
        // 校验存在
        validateTaskExists(id);
        // 删除
        taskMapper.deleteById(id);
    }

    private void validateTaskExists(Long id) {
        if (taskMapper.selectById(id) == null) {
            throw exception(TASK_NOT_EXISTS);
        }
    }

    @Override
    public RobotTaskDO getTask(Long id) {
        return taskMapper.selectById(id);
    }

    @Override
    public PageResult<RobotTaskDO> getTaskPage(RobotTaskPageReqVO pageReqVO) {
        return taskMapper.selectPage(pageReqVO);
    }

}